pub fn de_i64<'de, D: Deserializer<'de>>(d: D) -> Result<i64, D::Error>Expand description
An integer that may arrive as a number, a float, or a quoted string, with or
without a leading #.
pub fn de_i64<'de, D: Deserializer<'de>>(d: D) -> Result<i64, D::Error>An integer that may arrive as a number, a float, or a quoted string, with or
without a leading #.