pub struct PersistedState {
pub version: u32,
pub checkpoint: u64,
pub round: u32,
pub next_actor: String,
pub status: Status,
pub pr_head: String,
pub ledger: Ledger,
pub filed: Vec<String>,
pub open_findings: Vec<Finding>,
pub disputes: Vec<Dispute>,
pub noted: Vec<Finding>,
}Expand description
Everything needed to pick a review back up, including on another machine.
Fields
version: u32checkpoint: u64Monotonic checkpoint order for writes within this repository.
round: u32next_actor: Stringstatus: Statuspr_head: StringPublished pull request head to which this checkpoint applies.
ledger: Ledgerfiled: Vec<String>open_findings: Vec<Finding>disputes: Vec<Dispute>noted: Vec<Finding>Trait Implementations
Sourceimpl Clone for PersistedState
impl Clone for PersistedState
Sourcefn clone(&self) -> PersistedState
fn clone(&self) -> PersistedState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersistedState
impl Debug for PersistedState
Sourceimpl<'de> Deserialize<'de> for PersistedState
impl<'de> Deserialize<'de> for PersistedState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more