pub fn dedupe(texts: impl IntoIterator<Item = String>) -> Vec<String>Expand description
Collapse texts that make the same point, keeping the fullest wording of each.
pub fn dedupe(texts: impl IntoIterator<Item = String>) -> Vec<String>Collapse texts that make the same point, keeping the fullest wording of each.