pub fn gather(
repo: &Repo,
number: i64,
pr: bool,
seen: &Answered,
) -> Result<Gathered>Expand description
Everything on this pull request or issue that spar has not answered.
pr is false for an issue with no pull request, where there are no review
threads and no reviews to read.